@@ -43,7 +43,7 @@
 #include <ktexteditor_version.h>
 
 #include <QDebug>
-#include <QtTest/QtTest>
+#include <QtTest>
 
 using namespace Python;
 
